/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.core.functions;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.core.Type;
import pl.chyla.wyjec.core.Value;


/**
 * Base class for functions generating results of integer type.
 * Type of result is represented by value Type.INTEGER.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public abstract class IntegerFunction extends Function {

    /**
     * Evaluates the function's value for currently set parameters by calling {@link #execute()}
     * method and copies its result to passed {@link Value} object.
     *
     * @param result
     *     {@link Value} object to store function's result in; its type will be set to integer
     *     (<code>Type.INTEGER</code>)
     * @see Function#typedEvaluate(Value)
     */
    protected final void typedEvaluate(Value result) {
        result.setInteger(execute());
    }

    /**
     * Executes function's logic and evaluates result.
     *
     * @return result of the function's evaluation
     */
    protected abstract long execute();

    /**
     * @return type of result of the function; always returns Type.INTEGER
     * @see Function#getResultType()
     */
    public final Type getResultType() {
        return Type.INTEGER;
    }

}
