/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.core.parameters;

import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.Type;


/**
 * Represents function's declared parameter of type string. Instances of this class are used as
 * part of function's signature.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class StringParameter extends Parameter {

    /**
     * Constructs function's parameter of type {@link Type#STRING}.
     * <p>
     * Note: Before the parameter can be used, it must be bound to function's signature.
     */
    public StringParameter() {
        super();
    }

    /**
     * Returns type of the parameter; returned value is always <code>Type.STRING</code>.
     *
     * @return type of the parameter
     * @see Parameter#getType()
     */
    public Type getType() {
        return Type.STRING;
    }

}
