/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.extfuncs.mathfuncs;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.FloatFunction;
import pl.chyla.wyjec.core.parameters.FloatParameter;


/**
 * Trigonometric cosine function.
 *
 * @wyjec.func cos
 * @wyjec.example "{cos|{0.0}}" "1.0" float
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnCos extends FloatFunction {

    /**
     * Angle (in radians) to calculate cosine function for
     * @wyjec.param angle
     */
    private static final FloatParameter pAngle = new FloatParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pAngle}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "cos";
    }

    protected double execute() {
        return Math.cos(getParameter(pAngle));
    }

}
