/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.booleanfuncs;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.BooleanParameter;
import pl.chyla.wyjec.utils.RawString;


/**
 * Returns string representation of a parameter: "true" for boolean true and "false" for
 * boolean false.
 *
 * @wyjec.func str
 * @wyjec.example "{str|{false}}" "false" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnStr extends StringFunction {

    /**
     * Value to generate a string for
     * @wyjec.param value
     */
    private static final BooleanParameter pValue = new BooleanParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "str";
    }

    protected void execute(RawString result) {
        if (getParameter(pValue)) {
            result.append("true");
        } else {
            result.append("false");
        }
    }

}
