/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.FnDay;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.FnHour;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.FnMinute;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.FnMonth;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.FnSecond;
import pl.chyla.wyjec.stdfuncs.datefuncs.accessors.FnYear;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnAdditionDays;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnAdditionHours;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnAdditionMinutes;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnAdditionSeconds;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnSubtractionDays;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnSubtractionHours;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnSubtractionMinutes;
import pl.chyla.wyjec.stdfuncs.datefuncs.arithmetic.FnSubtractionSeconds;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.FnDateFromMilliseconds;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.FnDateFromYMD;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.FnDateFromYMDHMS;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.FnFormat;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.FnMidnight;
import pl.chyla.wyjec.stdfuncs.datefuncs.basic.FnStr;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.FnEqual;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.FnGreater;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.FnGreaterOrEqual;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.FnLess;
import pl.chyla.wyjec.stdfuncs.datefuncs.relations.FnLessOrEqual;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.FnIf;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.FnMax;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.FnMin;
import pl.chyla.wyjec.stdfuncs.datefuncs.selection.FnSelect;


/**
 * Factory for all standard functions operating on values of Wyjec's date type.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class DateFunctions {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private DateFunctions() { }

    /**
     * Returns array of {@link pl.chyla.wyjec.core.Function} instances representing all standard
     * date functions.
     *
     * @return new list of instances of standard date functions
     */
    public static Function[] getFunctions() {
        return new Function[] {
            new FnDateFromMilliseconds(), new FnDateFromYMD(), new FnDateFromYMDHMS(),
            new FnMidnight(),
            new FnAdditionSeconds(), new FnAdditionMinutes(), new FnAdditionHours(),
            new FnAdditionDays(),
            new FnSubtractionSeconds(), new FnSubtractionMinutes(), new FnSubtractionHours(),
            new FnSubtractionDays(),
            new FnSecond(), new FnMinute(), new FnHour(),
            new FnDay(), new FnMonth(), new FnYear(),
            new FnEqual(), new FnGreaterOrEqual(), new FnGreater(),
            new FnLessOrEqual(), new FnLess(),
            new FnMin(), new FnMax(), new FnIf(), new FnSelect(),
            new FnFormat(), new FnStr()};
    }

}
