/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.basic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.DateFunction;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Returns date value that corresponds to given nonnegative integer value containing number of
 * milliseconds since the Epoch (1970-01-01 00:00:00 UTC).
 *
 * @wyjec.func date
 * @wyjec.example "{date|{226713600000}}" "1977-03-09 00:00:00" date
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnDateFromMilliseconds extends DateFunction {

    /**
     * Number of milliseconds since 1970-01-01 00:00:00 UTC, value to be converted to date
     * @wyjec.param epochMilliseconds
     */
    private static final IntegerParameter pEpochMilliseconds = new IntegerParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pEpochMilliseconds}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "date";
    }

    protected long execute() {
        return getParameter(pEpochMilliseconds);
    }

}
