/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.datefuncs.selection;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.DateFunction;
import pl.chyla.wyjec.core.parameters.BooleanParameter;
import pl.chyla.wyjec.core.parameters.DateParameter;


/**
 * Returns one of two given date parameters, depending on value of condition given as
 * boolean parameter. If the condition is true, the function returns the first date,
 * otherwise it returns the second one.
 *
 * @wyjec.func if
 * @wyjec.example "{if|{>|5|2}|{&#64;1977-03-09}|{&#64;1978-09-11}}"
 * "1977-03-09 00:00:00" date
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnIf extends DateFunction {

    /**
     * Value that determines which date should be returned.
     * @wyjec.param condition
     */
    private static final BooleanParameter pCondition = new BooleanParameter();

    /**
     * First date parameter, returned as function's result if condition is true.
     * @wyjec.param date1
     */
    private static final DateParameter pDate1 = new DateParameter();

    /**
     * Second date parameter, returned as function's result if condition is false.
     * @wyjec.param date2
     */
    private static final DateParameter pDate2 = new DateParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pCondition, pDate1, pDate2}, null, true);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "if";
    }

    protected long execute() {
        if (getParameter(pCondition)) {
            return getParameter(pDate1);
        } else {
            return getParameter(pDate2);
        }
    }

}
