/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.FloatFunction;
import pl.chyla.wyjec.core.parameters.FloatParameter;


/**
 * Returns absolute value of number given as a parameter. For infinity with any sign the
 * function returns positive infinity. For <code>NaN</code> parameter the result is also
 * <code>NaN</code>.
 *
 * @wyjec.func abs
 * @wyjec.example "{abs|{-|{7.0}}}" "7.0" float
 * @wyjec.example "{abs|{/|{0.0}|{0.0}}}" "NaN" float
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnAbs extends FloatFunction {

    /**
     * Number to calculate absolute value for
     * @wyjec.param value
     */
    private static final FloatParameter pValue = new FloatParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "abs";
    }

    protected double execute() {
        return Math.abs(getParameter(pValue));
    }

}
