/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.floatfuncs.arithmetic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.FloatFunction;
import pl.chyla.wyjec.core.optparameters.FloatOptParameters;
import pl.chyla.wyjec.core.parameters.FloatParameter;


/**
 * Returns product of all numbers given as parameters. If any parameter is <code>NaN</code>,
 * the result is also <code>NaN</code>.
 *
 * @wyjec.func *
 * @wyjec.example "{*|{7.0}|{3.0}|{2.5}}" "52.5" float
 * @wyjec.example "{*|{7.0}|{/|{0.0}|{0.0}}|{2.5}}" "NaN" float
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnMultiplication extends FloatFunction {

    /**
     * First number (it will be copied to result in case its the only parameter)
     * @wyjec.param value
     */
    private static final FloatParameter pValue = new FloatParameter();

    /**
     * Other optional numbers to multiply by the first one
     * @wyjec.param optValues
     */
    private static final FloatOptParameters pOptValues = new FloatOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, pOptValues);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "*";
    }

    protected double execute() {
        double result = getParameter(pValue);
        int optParamsCount = getOptParametersCount(pOptValues);
        for (int i = 0; i < optParamsCount; i++) {
            result *= getParameter(pOptValues, i);
        }
        return result;
    }

}
