/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs;

import pl.chyla.wyjec.core.Function;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnAbs;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnAddition;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnDivision;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnDivisionWithDefault;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnModulo;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnModuloWithDefault;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnMultiplication;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnNegation;
import pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic.FnSubtraction;
import pl.chyla.wyjec.stdfuncs.integerfuncs.basic.FnIntFromDate;
import pl.chyla.wyjec.stdfuncs.integerfuncs.basic.FnIntFromFloat;
import pl.chyla.wyjec.stdfuncs.integerfuncs.basic.FnStr;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.FnEqual;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.FnGreater;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.FnGreaterOrEqual;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.FnLess;
import pl.chyla.wyjec.stdfuncs.integerfuncs.relations.FnLessOrEqual;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.FnIf;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.FnMax;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.FnMin;
import pl.chyla.wyjec.stdfuncs.integerfuncs.selection.FnSelect;


/**
 * Factory for all standard functions operating on values of Wyjec's integer type.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class IntegerFunctions {

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private IntegerFunctions() { }

    /**
     * Returns array of {@link pl.chyla.wyjec.core.Function} instances representing all standard
     * integer functions.
     *
     * @return new array of instances of standard integer functions
     */
    public static Function[] getFunctions() {
        return new Function[] {
            new FnAddition(), new FnSubtraction(), new FnNegation(), new FnAbs(),
            new FnMultiplication(), new FnDivision(), new FnDivisionWithDefault(),
            new FnModulo(), new FnModuloWithDefault(),
            new FnEqual(), new FnGreaterOrEqual(), new FnGreater(), new FnLessOrEqual(),
            new FnLess(),
            new FnMin(), new FnMax(),
            new FnIf(), new FnSelect(),
            new FnIntFromFloat(), new FnIntFromDate(), new FnStr()};
    }

}
