/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Returns absolute value of number given as a parameter with one important exception: due to
 * the nature of two's complement representation, for minimum integer value
 * (-9223372036854775808) this function will return value given as parameter, even if it's
 * negative.
 *
 * @wyjec.func abs
 * @wyjec.example "{abs|{-7}}" "7" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnAbs extends IntegerFunction {

    /**
     * Number to calculate absolute value for
     * @wyjec.param value
     */
    private static final IntegerParameter pValue = new IntegerParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "abs";
    }

    protected long execute() {
        return Math.abs(getParameter(pValue));
    }

}
