/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Returns the remainder from division of the first parameter by the second one (modulo
 * operation) or value of third parameter if divisor (second parameter) equals 0.
 *
 * @wyjec.func %
 * @wyjec.example "{%|{7}|{0}|{5}}" "5" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnModuloWithDefault extends IntegerFunction {

    /**
     * Value to divide by divisor
     * @wyjec.param divident
     */
    private static final IntegerParameter pDivident = new IntegerParameter();

    /**
     * Value that divident is to be divided by
     * @wyjec.param divisor
     */
    private static final IntegerParameter pDivisor = new IntegerParameter();

    /**
     * Value to use as result in case divisor equals 0
     * @wyjec.param defaultResult
     */
    private static final IntegerParameter pDefaultResult = new IntegerParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDivident, pDivisor, pDefaultResult}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "%";
    }

    protected long execute() {
        if (getParameter(pDivisor) != 0) {
            return getParameter(pDivident) % getParameter(pDivisor);
        } else {
            return getParameter(pDefaultResult);
        }
    }

}
