/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.integerfuncs.arithmetic;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.IntegerParameter;


/**
 * Returns arithmetic subtraction of two parameters.
 *
 * @wyjec.func -
 * @wyjec.example "{-|{7}|{3}}" "4" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnSubtraction extends IntegerFunction {

    /**
     * The number from which the subtrahend is to be subtracted
     * @wyjec.param minuend
     */
    private static final IntegerParameter pMinuend = new IntegerParameter();

    /**
     * The number to be subtracted from the minuend
     * @wyjec.param subtrahend
     */
    private static final IntegerParameter pSubtrahend = new IntegerParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pMinuend, pSubtrahend}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "-";
    }

    protected long execute() {
        return getParameter(pMinuend) - getParameter(pSubtrahend);
    }

}
