/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.IntegerFunction;
import pl.chyla.wyjec.core.parameters.StringParameter;


/**
 * Searches given string for another one contained in it and returns its 0-based index. If the
 * second string can't be found in the first one, this function returns <code>-1</code>.
 *
 * @wyjec.func find
 * @wyjec.example "{find|expression language|press}" "2" integer
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnFind extends IntegerFunction {

    /**
     * Base string to search for the substring in
     * @wyjec.param value
     */
    private static final StringParameter pValue = new StringParameter();

    /**
     * Substring to search for
     * @wyjec.param sub
     */
    private static final StringParameter pSub = new StringParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue, pSub}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "find";
    }

    protected long execute() {
        return getParameter(pValue).find(getParameter(pSub), 0);
    }

}
