/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.ops;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.RawString;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Returns a copy of string given as parameter with all characters converted to upper case.
 *
 * @wyjec.func upper
 * @wyjec.example "{upper|Kowalski}" "KOWALSKI" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnUpper extends StringFunction {

    /**
     * String to convert
     * @wyjec.param value
     */
    private static final StringParameter pValue = new StringParameter();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, null);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "upper";
    }

    protected void execute(RawString result) {
        ReadableRawString value = getParameter(pValue);
        char[] chars = value.getStorage();
        int startPos = value.getStartPos();
        int endPos = value.getEndPos();
        for (int i = startPos; i < endPos; i++) {
            result.append(Character.toUpperCase(chars[i]));
        }
    }

}
