/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.relations;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.BooleanFunction;
import pl.chyla.wyjec.core.optparameters.StringOptParameters;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.ReadableRawString;


/**
 * Returns boolean true if all parameters have the same value (have equal length and consist
 * of the same sequence of characters) and boolean false otherwise.
 *
 * @wyjec.func =
 * @wyjec.example "{=|33|{str|{33}}}" "true" boolean
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnEqual extends BooleanFunction {

    /**
     * First value used in comparision
     * @wyjec.param value
     */
    private static final StringParameter pValue = new StringParameter();

    /**
     * Other optional values to compare to the first one
     * @wyjec.param optValues
     */
    private static final StringOptParameters pOptValues = new StringOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pValue}, pOptValues);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "=";
    }

    protected boolean execute() {
        ReadableRawString firstValue = getParameter(pValue);
        int optParamsCount = getOptParametersCount(pOptValues);
        for (int i = 0; i < optParamsCount; i++) {
            if (!getParameter(pOptValues, i).equals(firstValue)) {
                return false;
            }
        }
        return true;
    }

}
