/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.stdfuncs.stringfuncs.selection;

import pl.chyla.wyjec.core.FunctionSignature;
import pl.chyla.wyjec.core.Parameter;
import pl.chyla.wyjec.core.functions.StringFunction;
import pl.chyla.wyjec.core.optparameters.StringOptParameters;
import pl.chyla.wyjec.core.parameters.IntegerParameter;
import pl.chyla.wyjec.core.parameters.StringParameter;
import pl.chyla.wyjec.utils.RawString;


/**
 * Returns one of given strings depending on value of selector. Selector specifies 0-based
 * index of string from given sequence of optional strings. In case index is negative or too
 * big, default string is returned.
 *
 * @wyjec.func select
 * @wyjec.example "{select|unknown|{3}|zero|one|two|three|four}" "three" string
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class FnSelect extends StringFunction {

    /**
     * Default string used as result of the function in case selector is negative or greater
     * than length of sequence of strings
     * @wyjec.param defaultValue
     */
    private static final StringParameter pDefaultValue = new StringParameter();

    /**
     * Index of value from sequence of strings to return as result
     * @wyjec.param selector
     */
    private static final IntegerParameter pSelector = new IntegerParameter();

    /**
     * Optional sequence of strings to select single value from (may be empty)
     * @wyjec.param optValues
     */
    private static final StringOptParameters pOptValues = new StringOptParameters();

    private static final FunctionSignature signature = new FunctionSignature(
        new Parameter[] {pDefaultValue, pSelector}, pOptValues, true);

    public FunctionSignature getSignature() {
        return signature;
    }

    public String getName() {
        return "select";
    }

    protected void execute(RawString result) {
        int selectorValue = (int) getParameter(pSelector);
        if (selectorValue >= 0 && selectorValue < getOptParametersCount(pOptValues)) {
            result.append(getParameter(pOptValues, selectorValue));
        } else {
            result.append(getParameter(pDefaultValue));
        }
    }

}
