/*
 * Wyjec - expression language, version 1.0
 * (c) Copyright by Zbigniew Chyla 2005
 *
 * This library is free software; you can redistribute it and/or modify it under the terms of
 * the GNU Lesser General Public License version 2.1 as published by the Free Software
 * Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with this
 * library; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301  USA
 */
package pl.chyla.wyjec.utils;


/**
 * Helper class grouping simple (and effective) operations on numbers of type <code>long</code>.
 *
 * @author Zbigniew Chyla (zbigniew@chyla.pl)
 */
public final class LongUtils {

    /**
     * Number of bits in values of type int.
     */
    public static final int LONG_BITS_COUNT = 64;

    /**
     * Private empty constructor to disallow instantiating of the class.
     */
    private LongUtils() { }

    /**
     * Compares two numbers for order. It's direct equivalent of
     * {@link java.util.Comparator#compare(java.lang.Object, java.lang.Object)} method but
     * operates on primitive values of type <code>long</code>.
     *
     * @param a first number to be compared
     * @param b second number to be compared
     * @return
     *     negative number, zero or positive number if first number is less, equal or greater
     *     than the second one.
     */
    public static int compare(long a, long b) {
        int result;
        if (a < b) {
            result = -1;
        } else if (a > b) {
            result = 1;
        } else {
            result = 0;
        }
        return result;
    }

    /**
     * Returns a value that may be used in an implementation of <code>Object.hashCode</code>
     * method, when a value of <code>long</code> type is one of data sources used to evaluate
     * hash code.
     *
     * @param value <code>long</code> value
     * @return hash code corresponding to given value
     */
    public static int hashCode(long value) {
        return (int) (value ^ value >> IntUtils.INT_BITS_COUNT);
    }

}
